package com.qmth.themis.business.util;

import com.qmth.themis.business.constant.SpringContextHolder;
import com.qmth.themis.business.constant.SystemConstant;
import org.springframework.data.redis.core.RedisTemplate;

import java.util.concurrent.TimeUnit;

/**
 * @Description: redis util
 * @Param:
 * @return:
 * @Author: wangliang
 * @Date: 2020/4/15
 */
public class RedisUtil {

    /**
     * 获取用户信息
     *
     * @param userId
     * @return
     */
    public static Object getUser(Long userId) {
        RedisTemplate redisTemplate = SpringContextHolder.getBean(RedisTemplate.class);
        return redisTemplate.opsForValue().get(SystemConstant.USER + userId);
    }

    /**
     * 获取用户会话信息
     *
     * @param sessionId
     * @return
     */
    public static Object getUserSession(String sessionId) {
        RedisTemplate redisTemplate = SpringContextHolder.getBean(RedisTemplate.class);
        return redisTemplate.opsForValue().get(SystemConstant.SESSION + sessionId);
    }

    /**
     * 删除用户缓存
     *
     * @param userId
     */
    public static void deleteUser(Long userId) {
        RedisTemplate redisTemplate = SpringContextHolder.getBean(RedisTemplate.class);
        redisTemplate.delete(SystemConstant.USER + userId);
    }

    /**
     * 删除用户会话缓存
     *
     * @param sessionId
     */
    public static void deleteUserSession(String sessionId) {
        RedisTemplate redisTemplate = SpringContextHolder.getBean(RedisTemplate.class);
        redisTemplate.delete(SystemConstant.SESSION + sessionId);
    }

    /**
     * 设置用户信息
     *
     * @param userId
     * @param o
     */
    public static void setUser(Long userId, Object o) {
        RedisTemplate redisTemplate = SpringContextHolder.getBean(RedisTemplate.class);
        redisTemplate.opsForValue().set(SystemConstant.USER + userId, o, SystemConstant.REDIS_EXPIRE_TIME, TimeUnit.SECONDS);
    }

    /**
     * 刷新用户缓存
     *
     * @param userId
     */
    public static void refreshUser(Long userId) {
        RedisTemplate redisTemplate = SpringContextHolder.getBean(RedisTemplate.class);
        redisTemplate.expire(SystemConstant.USER + userId, SystemConstant.REDIS_REFRESH_EXPIRE_TIME, TimeUnit.SECONDS);
    }

    /**
     * 获取用户缓存过期时间
     *
     * @param userId
     * @return
     */
    public static Long getUserExpire(Long userId) {
        RedisTemplate redisTemplate = SpringContextHolder.getBean(RedisTemplate.class);
        return redisTemplate.getExpire(SystemConstant.USER + userId, TimeUnit.SECONDS);
    }

    /**
     * 设置用户session信息
     *
     * @param sessionId
     * @param o
     */
    public static void setUserSession(String sessionId, Object o) {
        RedisTemplate redisTemplate = SpringContextHolder.getBean(RedisTemplate.class);
        redisTemplate.opsForValue().set(SystemConstant.SESSION + sessionId, o, SystemConstant.REDIS_EXPIRE_TIME, TimeUnit.SECONDS);
    }

    /**
     * 刷新用户session缓存
     *
     * @param sessionId
     */
    public static void refreshUserSession(String sessionId) {
        RedisTemplate redisTemplate = SpringContextHolder.getBean(RedisTemplate.class);
        redisTemplate.expire(SystemConstant.SESSION + sessionId, SystemConstant.REDIS_REFRESH_EXPIRE_TIME, TimeUnit.SECONDS);
    }

    /**
     * 获取用户session缓存过期时间
     *
     * @param sessionId
     * @return
     */
    public static Long getUserSessionExpire(String sessionId) {
        RedisTemplate redisTemplate = SpringContextHolder.getBean(RedisTemplate.class);
        return redisTemplate.getExpire(SystemConstant.SESSION + sessionId, TimeUnit.SECONDS);
    }
}